==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Spatial_searching/group__DistanceClasses.js <==
var group__DistanceClasses =
[
    [ "Euclidean_distance", "classCGAL_1_1Euclidean__distance.html", [
      [ "D", "classCGAL_1_1Euclidean__distance.html#af44518d66c58815bf2a68cfabbcc4140", null ],
      [ "FT", "classCGAL_1_1Euclidean__distance.html#a48ca155a8b9574f5ebd21bd5533fb843", null ],
      [ "Point_d", "classCGAL_1_1Euclidean__distance.html#a0c00f3a6987f2a9a7b2a46825bb496e6", null ],
      [ "Query_item", "classCGAL_1_1Euclidean__distance.html#a7412c41ee3a85b5065201e9f8bdf562e", null ],
      [ "Euclidean_distance", "classCGAL_1_1Euclidean__distance.html#ae53cc0d7e5ec6e8857d64570bf4ec5c9", null ],
      [ "interruptible_transformed_distance", "classCGAL_1_1Euclidean__distance.html#ad9092038dcdb236e8b6fa5a3d7ea44fd", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Euclidean__distance.html#abe782f9ba4ce8929fcee2f3d7e5cabf1", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a980887d3b78c726fa648812269de226b", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a9911577e27beb00546c3dcaffa608ec5", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a46ce687ec798ca7b33ed88151d7176de", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a731005188fcdf6c5514448fc540ede6b", null ],
      [ "new_distance", "classCGAL_1_1Euclidean__distance.html#abe84667ca8337fed2c08eb6e1dad3751", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance.html#ad11686ecf6f6e2888d3979f87e23de3d", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance.html#a9b534f360ca26151be0b33666622b6e8", null ],
      [ "transformed_distance_from_coordinates", "classCGAL_1_1Euclidean__distance.html#af379307b43d8660aa3ad34ab61e432e1", null ]
    ] ],
    [ "Euclidean_distance_sphere_point", "classCGAL_1_1Euclidean__distance__sphere__point.html", [
      [ "D", "classCGAL_1_1Euclidean__distance__sphere__point.html#aabc7c62f18c9ed705a8b6657e2f7e448", null ],
      [ "FT", "classCGAL_1_1Euclidean__distance__sphere__point.html#ad06a3349031cb081ad30a435ed7282d0", null ],
      [ "Point_d", "classCGAL_1_1Euclidean__distance__sphere__point.html#a489a6c69fec1816375cfaad722711df0", null ],
      [ "Sphere_d", "classCGAL_1_1Euclidean__distance__sphere__point.html#a9fd6c907cebb22a2f42a60f0ac513bb8", null ],
      [ "Euclidean_distance_sphere_point", "classCGAL_1_1Euclidean__distance__sphere__point.html#ab9409361f7ed24300b069cc852074bc3", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Euclidean__distance__sphere__point.html#a254874acb59c8bd6857bd79f87ec77ab", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Euclidean__distance__sphere__point.html#af96287115e78e54a34ed6c15c6f1ccf0", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Euclidean__distance__sphere__point.html#a9a53176a613f2eb5d70e50238a44c893", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance__sphere__point.html#aede7b77d8898e4ea019cba873f6d92e3", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance__sphere__point.html#a1f5de1466a4108a7d85cc1f8f56d9924", null ]
    ] ],
    [ "Manhattan_distance_iso_box_point", "classCGAL_1_1Manhattan__distance__iso__box__point.html", [
      [ "D", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a77db67712228846bbaaace47a9751c86", null ],
      [ "FT", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a5f1021d6f15ff1364d5482e760180409", null ],
      [ "Point_d", "classCGAL_1_1Manhattan__distance__iso__box__point.html#afe1ccd6dcc314b476ca6ed65160e969a", null ],
      [ "Query_item", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a086999aaaffc45005f7646750b49cb4d", null ],
      [ "Manhattan_distance_iso_box_point", "classCGAL_1_1Manhattan__distance__iso__box__point.html#ab8fcc62162ddbcb9618b420145808eb4", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a1d6e589a0eb5048fe4422d82e17163b9", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a29035b4c250f9f87f98c298e4bf5e216", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a492c615f0b765280f35f06132fc67904", null ],
      [ "transformed_distance", "classCGAL_1_1Manhattan__distance__iso__box__point.html#ad5f8228bdc51066bf3087d257da78bd4", null ],
      [ "transformed_distance", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a6c4cc5e886b30623f5f71f75761d4c85", null ]
    ] ],
    [ "Distance_adapter", "classCGAL_1_1Distance__adapter.html", [
      [ "FT", "classCGAL_1_1Distance__adapter.html#a1e8833285d81f871a3ce7b73be93fd3d", null ],
      [ "Point_d", "classCGAL_1_1Distance__adapter.html#a763da96f2a8ee88d74780964df59b09c", null ],
      [ "Query_item", "classCGAL_1_1Distance__adapter.html#a9435231e0d6a745466edc27d46fad148", null ],
      [ "Distance_adapter", "classCGAL_1_1Distance__adapter.html#a5a4d314c40dda35373ea1062abd0186a", null ],
      [ "point_property_map", "classCGAL_1_1Distance__adapter.html#a6b7c8ef9941865c4683ecef13c45d391", null ]
    ] ],
    [ "Weighted_Minkowski_distance", "classCGAL_1_1Weighted__Minkowski__distance.html", [
      [ "D", "classCGAL_1_1Weighted__Minkowski__distance.html#aaf10682af16983e360fc316879887d77", null ],
      [ "FT", "classCGAL_1_1Weighted__Minkowski__distance.html#ad4642605161b3185a76d7ec6e02100bd", null ],
      [ "Point_d", "classCGAL_1_1Weighted__Minkowski__distance.html#aee8d127441a582c5fe5bd2c62ae86dbf", null ],
      [ "Weighted_Minkowski_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#ac9ecdcde819c19c1e1301c8de056b11b", null ],
      [ "Weighted_Minkowski_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a0fa557548ccefcdeb03fdb416389b33e", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#acbe7147002c592bb0d68acdc7a0f58e6", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#a5509eca4a4de3b69b5465878284d90e5", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#aa2d3ffeaee933d4189e4f213e7387436", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#a11774bb64e1596ae85627a97cd17d2f5", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#acf18ccb77d85f776a89a5973da68d63f", null ],
      [ "new_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a002a4919bcd39604bd6fd1cbff66c45b", null ],
      [ "transformed_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a71188dda5c8b38143e1b9a83b8bd96e1", null ],
      [ "transformed_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a25224d5b0b30ce2474551f1e35842917", null ]
    ] ]
];

==> CGAL-6.0-doc_html.tar.xz: doc_html/Spatial_searching/group__DistanceClasses.js <==
var group__DistanceClasses =
[
    [ "CGAL::Euclidean_distance< Traits >", "classCGAL_1_1Euclidean__distance.html", [
      [ "D", "classCGAL_1_1Euclidean__distance.html#af44518d66c58815bf2a68cfabbcc4140", null ],
      [ "FT", "classCGAL_1_1Euclidean__distance.html#a48ca155a8b9574f5ebd21bd5533fb843", null ],
      [ "Point_d", "classCGAL_1_1Euclidean__distance.html#a0c00f3a6987f2a9a7b2a46825bb496e6", null ],
      [ "Query_item", "classCGAL_1_1Euclidean__distance.html#a7412c41ee3a85b5065201e9f8bdf562e", null ],
      [ "Euclidean_distance", "classCGAL_1_1Euclidean__distance.html#ae53cc0d7e5ec6e8857d64570bf4ec5c9", null ],
      [ "interruptible_transformed_distance", "classCGAL_1_1Euclidean__distance.html#ad9092038dcdb236e8b6fa5a3d7ea44fd", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Euclidean__distance.html#abe782f9ba4ce8929fcee2f3d7e5cabf1", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a980887d3b78c726fa648812269de226b", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a9911577e27beb00546c3dcaffa608ec5", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a46ce687ec798ca7b33ed88151d7176de", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Euclidean__distance.html#a731005188fcdf6c5514448fc540ede6b", null ],
      [ "new_distance", "classCGAL_1_1Euclidean__distance.html#abe84667ca8337fed2c08eb6e1dad3751", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance.html#a9b534f360ca26151be0b33666622b6e8", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance.html#ad11686ecf6f6e2888d3979f87e23de3d", null ],
      [ "transformed_distance_from_coordinates", "classCGAL_1_1Euclidean__distance.html#af379307b43d8660aa3ad34ab61e432e1", null ]
    ] ],
    [ "CGAL::Euclidean_distance_sphere_point< Traits >", "classCGAL_1_1Euclidean__distance__sphere__point.html", [
      [ "D", "classCGAL_1_1Euclidean__distance__sphere__point.html#aabc7c62f18c9ed705a8b6657e2f7e448", null ],
      [ "FT", "classCGAL_1_1Euclidean__distance__sphere__point.html#ad06a3349031cb081ad30a435ed7282d0", null ],
      [ "Point_d", "classCGAL_1_1Euclidean__distance__sphere__point.html#a489a6c69fec1816375cfaad722711df0", null ],
      [ "Sphere_d", "classCGAL_1_1Euclidean__distance__sphere__point.html#a9fd6c907cebb22a2f42a60f0ac513bb8", null ],
      [ "Euclidean_distance_sphere_point", "classCGAL_1_1Euclidean__distance__sphere__point.html#ab9409361f7ed24300b069cc852074bc3", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Euclidean__distance__sphere__point.html#a254874acb59c8bd6857bd79f87ec77ab", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Euclidean__distance__sphere__point.html#af96287115e78e54a34ed6c15c6f1ccf0", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Euclidean__distance__sphere__point.html#a9a53176a613f2eb5d70e50238a44c893", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance__sphere__point.html#a1f5de1466a4108a7d85cc1f8f56d9924", null ],
      [ "transformed_distance", "classCGAL_1_1Euclidean__distance__sphere__point.html#aede7b77d8898e4ea019cba873f6d92e3", null ]
    ] ],
    [ "CGAL::Manhattan_distance_iso_box_point< Traits >", "classCGAL_1_1Manhattan__distance__iso__box__point.html", [
      [ "D", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a77db67712228846bbaaace47a9751c86", null ],
      [ "FT", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a5f1021d6f15ff1364d5482e760180409", null ],
      [ "Point_d", "classCGAL_1_1Manhattan__distance__iso__box__point.html#afe1ccd6dcc314b476ca6ed65160e969a", null ],
      [ "Query_item", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a086999aaaffc45005f7646750b49cb4d", null ],
      [ "Manhattan_distance_iso_box_point", "classCGAL_1_1Manhattan__distance__iso__box__point.html#ab8fcc62162ddbcb9618b420145808eb4", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a1d6e589a0eb5048fe4422d82e17163b9", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a29035b4c250f9f87f98c298e4bf5e216", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a492c615f0b765280f35f06132fc67904", null ],
      [ "transformed_distance", "classCGAL_1_1Manhattan__distance__iso__box__point.html#a6c4cc5e886b30623f5f71f75761d4c85", null ],
      [ "transformed_distance", "classCGAL_1_1Manhattan__distance__iso__box__point.html#ad5f8228bdc51066bf3087d257da78bd4", null ]
    ] ],
    [ "CGAL::Distance_adapter< Key, PointPropertyMap, Base_distance >", "classCGAL_1_1Distance__adapter.html", [
      [ "FT", "classCGAL_1_1Distance__adapter.html#a1e8833285d81f871a3ce7b73be93fd3d", null ],
      [ "Point_d", "classCGAL_1_1Distance__adapter.html#a763da96f2a8ee88d74780964df59b09c", null ],
      [ "Query_item", "classCGAL_1_1Distance__adapter.html#a9435231e0d6a745466edc27d46fad148", null ],
      [ "Distance_adapter", "classCGAL_1_1Distance__adapter.html#a5a4d314c40dda35373ea1062abd0186a", null ],
      [ "point_property_map", "classCGAL_1_1Distance__adapter.html#a74dcd35f9373cbd27c33138e55a5148e", null ]
    ] ],
    [ "CGAL::Weighted_Minkowski_distance< Traits >", "classCGAL_1_1Weighted__Minkowski__distance.html", [
      [ "D", "classCGAL_1_1Weighted__Minkowski__distance.html#aaf10682af16983e360fc316879887d77", null ],
      [ "FT", "classCGAL_1_1Weighted__Minkowski__distance.html#ad4642605161b3185a76d7ec6e02100bd", null ],
      [ "Point_d", "classCGAL_1_1Weighted__Minkowski__distance.html#aee8d127441a582c5fe5bd2c62ae86dbf", null ],
      [ "Weighted_Minkowski_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#ac9ecdcde819c19c1e1301c8de056b11b", null ],
      [ "Weighted_Minkowski_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a0fa557548ccefcdeb03fdb416389b33e", null ],
      [ "inverse_of_transformed_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#acbe7147002c592bb0d68acdc7a0f58e6", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#a5509eca4a4de3b69b5465878284d90e5", null ],
      [ "max_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#aa2d3ffeaee933d4189e4f213e7387436", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#a11774bb64e1596ae85627a97cd17d2f5", null ],
      [ "min_distance_to_rectangle", "classCGAL_1_1Weighted__Minkowski__distance.html#acf18ccb77d85f776a89a5973da68d63f", null ],
      [ "new_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a002a4919bcd39604bd6fd1cbff66c45b", null ],
      [ "transformed_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a25224d5b0b30ce2474551f1e35842917", null ],
      [ "transformed_distance", "classCGAL_1_1Weighted__Minkowski__distance.html#a71188dda5c8b38143e1b9a83b8bd96e1", null ]
    ] ]
];
